@@ -14,15 +14,25 @@ macro_rules! params {
 
 #[macro_export]
 macro_rules! table {
-	($name:tt{$($rust_key:ident $rust_type:ty : $db_name:tt $db_type:expr ),+}) => {
-		#[derive(Debug)]
-		struct $name {
+	(
+		$(#[$($meta:meta),*])?
+		$pub:vis $name:ident
+		{
+			$(
+				$(#[$($inner_meta:meta),*])?
+				$rust_key:ident $rust_type:ty : $db_name:tt $db_type:expr
+			 ),+
+		}
+	) => {
+		$(#[$($meta),*])?
+		$pub struct $name {
 		$(
+			$(#[$($inner_meta),*])?
 			$rust_key:$rust_type
 		),+
 		}
 		impl $name{
-			pub fn new($($rust_key:$rust_type),+) -> $name{
+			pub fn __new($($rust_key:$rust_type),+) -> $name{
 				Self{
 					$($rust_key),+
 				}
@@ -31,7 +41,7 @@ macro_rules! table {
 				let fields = [
 					$(concat!("\"",stringify!($db_name),"\""," ",$db_type)),+
 				];
-				format!("CREATE TABLE IF NOT EXISTS {} ({})",stringify!($name).to_lowercase(),fields.join(","))
+				format!("CREATE TABLE IF NOT EXISTS {} ({});",stringify!($name).to_lowercase(),fields.join(","))
 			}
 		}
 		impl $crate::Table for $name{
@@ -39,15 +49,13 @@ macro_rules! table {
 				stringify!($name).to_lowercase()
 			}
 		}
-		#[cfg(feature="tokio_postgres")]
 		impl From<&$crate::Row> for $name{
 			fn from(r:&$crate::Row)->Self{
 				Self{
-					$($rust_key:r.get(stringify!($rust_key))),+
+					$($rust_key:r.get(stringify!($db_name))),+
 				}
 			}
 		}
-		#[cfg(feature="tokio_postgres")]
 		impl From<$crate::Row> for $name{
 			fn from(r:$crate::Row)->Self{
 				Self::from(&r)
